==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGroupingDoneEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGroupingDoneEventArgsDetailDescription, _super);
    function WebGroupingDoneEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.k = null;
        _this.l = null;
        _this.m = null;
        return _this;
    }
    WebGroupingDoneEventArgsDetailDescription.prototype.get_type = function () {
        return "WebGroupingDoneEventArgsDetail";
    };
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "expressions", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("Expressions");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "groupedColumns", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("GroupedColumns");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "ungroupedColumns", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.e("UngroupedColumns");
        },
        enumerable: true,
        configurable: true
    });
    WebGroupingDoneEventArgsDetailDescription.$t = markType(WebGroupingDoneEventArgsDetailDescription, 'WebGroupingDoneEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebGroupingDoneEventArgsDetailDescription.__marshalByValue1 = true;
    WebGroupingDoneEventArgsDetailDescription.__marshalByValueAlias1 = "GroupingDoneEventArgsDetail";
    return WebGroupingDoneEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebGroupingDoneEventArgsDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebGroupingDoneEventArgsDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebBaseEventArgsDetailDescription } from "./WebBaseEventArgsDetailDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebGroupingDoneEventArgsDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGroupingDoneEventArgsDetailDescription, _super);
    function WebGroupingDoneEventArgsDetailDescription() {
        var _this = _super.call(this) || this;
        _this.m = null;
        _this.n = null;
        _this.o = null;
        return _this;
    }
    WebGroupingDoneEventArgsDetailDescription.prototype.get_type = function () {
        return "WebGroupingDoneEventArgsDetail";
    };
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "expressions", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("Expressions");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "groupedColumns", {
        get: function () {
            return this.n;
        },
        set: function (a) {
            this.n = a;
            this.g("GroupedColumns");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebGroupingDoneEventArgsDetailDescription.prototype, "ungroupedColumns", {
        get: function () {
            return this.o;
        },
        set: function (a) {
            this.o = a;
            this.g("UngroupedColumns");
        },
        enumerable: false,
        configurable: true
    });
    WebGroupingDoneEventArgsDetailDescription.$t = markType(WebGroupingDoneEventArgsDetailDescription, 'WebGroupingDoneEventArgsDetailDescription', WebBaseEventArgsDetailDescription.$);
    WebGroupingDoneEventArgsDetailDescription.__marshalByValue1 = true;
    WebGroupingDoneEventArgsDetailDescription.__marshalByValueAlias1 = "GroupingDoneEventArgsDetail";
    return WebGroupingDoneEventArgsDetailDescription;
}(WebBaseEventArgsDetailDescription));
export { WebGroupingDoneEventArgsDetailDescription };
